@@ -1,5 +1,5 @@
 from reinforced_lib.agents.base_agent import BaseAgent, AgentState
 from reinforced_lib.agents.e_greedy import EGreedy
-from reinforced_lib.agents.gradient_bandit import GradientBandit
+from reinforced_lib.agents.softmax import Softmax
 from reinforced_lib.agents.thompson_sampling import ThompsonSampling
 from reinforced_lib.agents.ucb import UCB
